@@ -5,7 +5,7 @@
 # devices and changing Hatari command line options (even for things you
 # cannot change from the UI) from the console while Hatari is running.
 #
-# Copyright (C) 2008-2014 by Eero Tamminen
+# Copyright (C) 2008-2020 by Eero Tamminen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -173,7 +173,7 @@ class Hatari:
         else:
             # child runs Hatari
             allargs = [self.hataribin, "--control-socket", self.controlpath] + args
-            print("RUN:", allargs)
+            print('RUN: "%s"' % ' '.join(allargs))
             os.execvp(self.hataribin, allargs)
 
     def send_message(self, msg, fast = False):
@@ -305,22 +305,29 @@ class Tokens:
     "--configfile",
     "--keymap",
     "--fast-forward",
+    "--auto",
     "--mono",
     "--monitor",
+    "--tos-res",
     "--fullscreen",
     "--window",
     "--grab",
+    "--resizable",
     "--frameskips",
+    "--slowdown",
+    "--mousewarp",
     "--statusbar",
     "--drive-led",
+    "--max-width",
+    "--max-height",
+    "--zoom",
     "--bpp",
+    "--disable-video",
     "--borders",
     "--desktop-st",
     "--spec512",
-    "--zoom",
+    "--video-timing",
     "--desktop",
-    "--max-width",
-    "--max-height",
     "--force-max",
     "--aspect",
     "--vdi",
@@ -330,8 +337,10 @@ class Tokens:
     "--crop",
     "--avirecord",
     "--avi-vcodec",
+    "--png-level",
     "--avi-fps",
     "--avi-file",
+    "--screenshot-dir",
     "--joy0",
     "--joy1",
     "--joy2",
@@ -344,18 +353,28 @@ class Tokens:
     "--midi-out",
     "--rs232-in",
     "--rs232-out",
-#    "--scc-b-in",
     "--scc-b-out",
+    "--drive-a",
+    "--drive-b",
+    "--drive-a-heads",
+    "--drive-b-heads",
     "--disk-a",
     "--disk-b",
     "--fastfdc",
     "--protect-floppy",
-    "--protect-hd",
     "--harddrive",
+    "--protect-hd",
+    "--gemdos-case",
+    "--gemdos-time",
+    "--gemdos-conv",
+    "--gemdos-drive",
     "--acsi",
+    "--scsi",
     "--ide-master",
     "--ide-slave",
+    "--ide-swap",
     "--memsize",
+    "--ttram",
     "--memstate",
     "--tos",
     "--patch-tos",
@@ -363,28 +382,39 @@ class Tokens:
     "--cpulevel",
     "--cpuclock",
     "--compatible",
+    "--cpu-exact",
+    "--addr24",
+    "--fpu",
+    "--fpu-softfloat",
+    "--mmu",
     "--machine",
     "--blitter",
     "--dsp",
     "--timer-d",
     "--fast-boot",
-    "--rtc",
     "--mic",
     "--sound",
     "--sound-buffer-size",
+    "--sound-sync",
     "--ym-mixing",
     "--debug",
+    "--debug-except",
+    "--lilo",
     "--bios-intercept",
     "--conout",
+    "--disasm",
+    "--natfeats",
     "--trace",
     "--trace-file",
     "--parse",
     "--saveconfig",
     "--no-parachute",
+    "--cmd-fifo",
     "--log-file",
     "--log-level",
     "--alert-level",
-    "--run-vbls"
+    "--run-vbls",
+    "--benchmark"
     ]
     shortcut_tokens = [
     "mousegrab",
